@@ -45,7 +45,7 @@
  *
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: collector.c,v 1.5 2005/01/06 20:51:49 martinp Exp $
+ *  @version \$Id: collector.c,v 1.6 2005/04/05 19:52:57 martinp Exp $
  *
  *  @file
  */
@@ -99,7 +99,7 @@ void handle_collector(Event_T E) {
     }
   }
 
-  D = status_xml(E);
+  D = status_xml(E, LEVEL_FULL);
 
   if(!data_send(C, D))
   {
