@@ -82,10 +82,6 @@
 #define RUN         "/_runtime"
 #define VIEWLOG     "/_viewlog"
 
-/* Status output formats */
-#define XML_STATUS   0
-#define TEXT_STATUS  1
-
 /* Private prototypes */
 static int is_readonly(HttpRequest);
 static void printPixel(HttpResponse);
@@ -127,9 +123,9 @@ static void print_service_params_device(HttpResponse, Service_T);
 static void print_service_params_size(HttpResponse, Service_T);
 static void print_service_params_checksum(HttpResponse, Service_T);
 static void print_service_params_process(HttpResponse, Service_T);
-static void print_status(HttpResponse, int);
-static void status_system_txt(HttpResponse);
-static void status_service_txt(Service_T, HttpResponse);
+static void print_status(HttpRequest, HttpResponse);
+static void status_system_txt(HttpResponse, short);
+static void status_service_txt(Service_T, HttpResponse, short);
 static char *get_service_status_html(Service_T);
 static char *get_service_status_text(Service_T);
 
@@ -144,7 +140,7 @@ static char *get_service_status_text(Service_T);
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: cervlet.c,v 1.184 2005/02/20 23:14:46 hauk Exp $
+ *  @version \$Id: cervlet.c,v 1.186 2005/04/05 19:52:57 martinp Exp $
  *
  *  @file
  */
@@ -220,13 +216,7 @@ static void doGet(HttpRequest req, HttpResponse res) {
   } else if(ACTION(PIXEL)) {
     printPixel(res);
   } else if(ACTION(STATUS)) {
-    const char *format= get_parameter(req, "format");
-    if(format && Util_startsWith(format, "xml"))
-      print_status(res, XML_STATUS);
-    else {
-      /* Text status output is default */
-      print_status(res, TEXT_STATUS);
-    }
+    print_status(req, res);
   } else {
     handle_action(req, res);
   }
@@ -2076,168 +2066,194 @@ static int is_readonly(HttpRequest req) {
 
 
 /* Print status in the given format. Text status is default. */
-static void print_status(HttpResponse res, int format) {
-
+static void print_status(HttpRequest req, HttpResponse res)
+{
   Service_T s;
+  short level = LEVEL_FULL;
+  const char *stringFormat = get_parameter(req, "format");
+  const char *stringLevel = get_parameter(req, "level");
 
-  if(format==XML_STATUS)
+  if(stringLevel && Util_startsWith(stringLevel, LEVEL_NAME_SUMMARY))
   {
-    char *D;
+    level = LEVEL_SUMMARY;
+  }
 
-    set_content_type(res, "text/xml");
-    D = status_xml(NULL);
+  if(stringFormat && Util_startsWith(stringFormat, "xml"))
+  {
+    char *D = status_xml(NULL, level);
     out_print(res, "%s", D);
     FREE(D);
+    set_content_type(res, "text/xml");
   }
   else
   {
-    set_content_type(res, "text/plain");
-    if(Run.doprocess) {
-      status_system_txt(res);
+    char *uptime = Util_getUptime(Util_getProcessUptime(Run.pidfile), " ");
+    out_print(res, "The monit daemon %s uptime: %s\n\n", VERSION, uptime);
+    FREE(uptime);
+
+    if(Run.doprocess)
+    {
+      status_system_txt(res, level);
     }
     for(s= servicelist_conf; s; s= s->next_conf)
     {
-      status_service_txt(s, res);
+      status_service_txt(s, res, level);
     }
+    set_content_type(res, "text/plain");
   }
 }
 
 
-static void status_system_txt(HttpResponse res) {
+static void status_system_txt(HttpResponse res, short level) {
+  char time[STRLEN];
 
-  char *uptime;
-  char  time[STRLEN];
+  if(level == LEVEL_SUMMARY)
+  {
+    char prefix[STRLEN];
 
-  uptime= Util_getUptime(Util_getProcessUptime(Run.pidfile), " ");
-  out_print(res,
-    "The monit daemon %s uptime: %s\n\n", VERSION, uptime);
-  FREE(uptime);
-
-  ctime_r(&systeminfo.collected, time);
-  out_print(res,
-    "System '%s'\n"
-    "  %-33s [%.2f] [%.2f] [%.2f]\n"
-    "  %-33s %.1f%%us %.1f%%sy"
-  #ifdef HAVE_CPU_WAIT
-    " %.1f%%wa"
-  #endif
-    "\n"
-    "  %-33s %ld kB [%.1f%%]\n"
-    "  %-33s %s",
-    Run.localhostname,
-    "load average",
-    systeminfo.loadavg[0],
-    systeminfo.loadavg[1],
-    systeminfo.loadavg[2],
-    "cpu",
-    systeminfo.total_cpu_user_percent/10.,
-    systeminfo.total_cpu_syst_percent/10.,
-  #ifdef HAVE_CPU_WAIT
-    systeminfo.total_cpu_wait_percent/10.,
-  #endif
-    "memory usage",
-    systeminfo.total_mem_kbyte,
-    systeminfo.total_mem_percent/10.,
-    "data collected",
-    time);
-
-  out_print(res, "\n");
+    snprintf(prefix, STRLEN, "System '%s'", Run.localhostname);
+    out_print(res, "%-35s [%.2f] [%.2f] [%.2f]\n",
+      prefix,
+      systeminfo.loadavg[0],
+      systeminfo.loadavg[1],
+      systeminfo.loadavg[2]);
+  }
+  else
+  {
+    ctime_r(&systeminfo.collected, time);
+    out_print(res,
+      "System '%s'\n"
+      "  %-33s [%.2f] [%.2f] [%.2f]\n"
+      "  %-33s %.1f%%us %.1f%%sy"
+    #ifdef HAVE_CPU_WAIT
+      " %.1f%%wa"
+    #endif
+      "\n"
+      "  %-33s %ld kB [%.1f%%]\n"
+      "  %-33s %s\n",
+      Run.localhostname,
+      "load average",
+      systeminfo.loadavg[0],
+      systeminfo.loadavg[1],
+      systeminfo.loadavg[2],
+      "cpu",
+      systeminfo.total_cpu_user_percent/10.,
+      systeminfo.total_cpu_syst_percent/10.,
+    #ifdef HAVE_CPU_WAIT
+      systeminfo.total_cpu_wait_percent/10.,
+    #endif
+      "memory usage",
+      systeminfo.total_mem_kbyte,
+      systeminfo.total_mem_percent/10.,
+      "data collected",
+      time);
+  }
 
 }
 
 
-static void status_service_txt(Service_T s, HttpResponse res) {
-  char  time[STRLEN];
-  char *status;
-  status= get_service_status_text(s);
-  out_print(res,
+static void status_service_txt(Service_T s, HttpResponse res, short level) {
+  char *status = get_service_status_text(s);
+
+  if(level == LEVEL_SUMMARY)
+  {
+    char prefix[STRLEN];
+
+    snprintf(prefix, STRLEN, "%s '%s'", servicetypes[s->type], s->name);
+    out_print(res, "%-35s %s\n", prefix, status);
+  }
+  else
+  {
+    char time[STRLEN];
+
+    out_print(res,
 	    "%s '%s'\n"
 	    "  %-33s %s\n"
 	    "  %-33s %s\n",
 	    servicetypes[s->type], s->name,
 	    "status", status,
 	    "monitoring status", monitornames[s->monitor]);
-  FREE(status);
-  if(Util_hasServiceStatus(s)) {
-    if(s->type == TYPE_FILE || s->type == TYPE_DIRECTORY || 
-       s->type == TYPE_DEVICE) {
-      out_print(res,
-		"  %-33s %o\n"
-		"  %-33s %d\n"
-		"  %-33s %d\n",
-		"permission", s->inf->st_mode & 07777,
-		"uid", (int)s->inf->st_uid,
-		"gid", (int)s->inf->st_gid);
-    }
-    if(s->type == TYPE_FILE || s->type == TYPE_DIRECTORY) {
-      ctime_r(&s->inf->timestamp, time);
-      out_print(res,
-		"  %-33s %s",
-		"timestamp", time);
-    }
-    if(s->type == TYPE_FILE) {
-      out_print(res,
-		"  %-33s %lu B\n",
-		"size", (unsigned long) s->inf->st_size);
-      if(s->checksum) {
-	out_print(res,
-		  "  %-33s %s(%s)\n",
-		  "checksum", s->inf->cs_sum, 
-		  checksumnames[s->checksum->type]);
+
+    if(Util_hasServiceStatus(s)) {
+      if(s->type == TYPE_FILE || s->type == TYPE_DIRECTORY || 
+         s->type == TYPE_DEVICE) {
+        out_print(res,
+  		"  %-33s %o\n"
+  		"  %-33s %d\n"
+  		"  %-33s %d\n",
+  		"permission", s->inf->st_mode & 07777,
+  		"uid", (int)s->inf->st_uid,
+  		"gid", (int)s->inf->st_gid);
       }
-    }
-    if(s->type == TYPE_DEVICE) {
-      out_print(res,
-		"  %-33s %ld B\n"
-		"  %-33s %ld [%.1f MB]\n"
-		"  %-33s %ld [%.1f MB] [%.1f%%]\n"
-		"  %-33s %ld [%.1f MB] [%.1f%%]\n",
-		"block size",
-		s->inf->f_bsize,
-		"blocks total",
-		s->inf->f_blocks,
-		((float)s->inf->f_blocks/(float)1048576*
-		 (float)s->inf->f_bsize),
-		"blocks free for non superuser",
-		s->inf->f_blocksfree,
-		((float)s->inf->f_blocksfree/(float)1048576*
-		 (float)s->inf->f_bsize),
-		((float)100*(float)s->inf->f_blocksfree/
-		 (float)s->inf->f_blocks),
-		"blocks free total",
-		s->inf->f_blocksfreetotal,
-		((float)s->inf->f_blocksfreetotal/(float)1048576*
-		 (float)s->inf->f_bsize),
-		((float)100*(float)s->inf->f_blocksfreetotal/
-		 (float)s->inf->f_blocks));
-      if(s->inf->f_files > 0) {
-	out_print(res,
-		  "  %-33s %ld\n"
-		  "  %-33s %ld [%.1f%%]\n",
-		  "inodes total",
-		  s->inf->f_files,
-		  "inodes free",
-		  s->inf->f_filesfree,
-		  ((float)100*(float)s->inf->f_filesfree/
-		   (float)s->inf->f_files));
+      if(s->type == TYPE_FILE || s->type == TYPE_DIRECTORY) {
+        ctime_r(&s->inf->timestamp, time);
+        out_print(res,
+  		"  %-33s %s",
+  		"timestamp", time);
       }
-    }
-    if(s->type == TYPE_PROCESS) {
-      char *uptime= Util_getUptime(s->inf->uptime, " ");
-      out_print(res,
-		"  %-33s %d\n"
-		"  %-33s %d\n"
-		"  %-33s %s\n",
-		"pid", s->inf->pid,
-		"parent pid", s->inf->ppid,
-		"uptime", uptime);
-      FREE(uptime);
-      if(Run.doprocess)	{
-	out_print(res,
-		  "  %-33s %d\n"
-		  "  %-33s %ld\n"
-		  "  %-33s %ld\n"
-		  "  %-33s %.1f%%\n"
+      if(s->type == TYPE_FILE) {
+        out_print(res,
+  		"  %-33s %lu B\n",
+  		"size", (unsigned long) s->inf->st_size);
+        if(s->checksum) {
+  	out_print(res,
+  		  "  %-33s %s(%s)\n",
+  		  "checksum", s->inf->cs_sum, 
+  		  checksumnames[s->checksum->type]);
+        }
+      }
+      if(s->type == TYPE_DEVICE) {
+        out_print(res,
+  		"  %-33s %ld B\n"
+  		"  %-33s %ld [%.1f MB]\n"
+  		"  %-33s %ld [%.1f MB] [%.1f%%]\n"
+  		"  %-33s %ld [%.1f MB] [%.1f%%]\n",
+  		"block size",
+  		s->inf->f_bsize,
+  		"blocks total",
+  		s->inf->f_blocks,
+  		((float)s->inf->f_blocks/(float)1048576*
+  		 (float)s->inf->f_bsize),
+  		"blocks free for non superuser",
+  		s->inf->f_blocksfree,
+  		((float)s->inf->f_blocksfree/(float)1048576*
+  		 (float)s->inf->f_bsize),
+  		((float)100*(float)s->inf->f_blocksfree/
+  		 (float)s->inf->f_blocks),
+  		"blocks free total",
+  		s->inf->f_blocksfreetotal,
+  		((float)s->inf->f_blocksfreetotal/(float)1048576*
+  		 (float)s->inf->f_bsize),
+  		((float)100*(float)s->inf->f_blocksfreetotal/
+  		 (float)s->inf->f_blocks));
+        if(s->inf->f_files > 0) {
+  	out_print(res,
+  		  "  %-33s %ld\n"
+  		  "  %-33s %ld [%.1f%%]\n",
+  		  "inodes total",
+  		  s->inf->f_files,
+  		  "inodes free",
+  		  s->inf->f_filesfree,
+  		  ((float)100*(float)s->inf->f_filesfree/
+  		   (float)s->inf->f_files));
+        }
+      }
+      if(s->type == TYPE_PROCESS) {
+        char *uptime= Util_getUptime(s->inf->uptime, " ");
+        out_print(res,
+  		"  %-33s %d\n"
+  		"  %-33s %d\n"
+  		"  %-33s %s\n",
+    		"pid", s->inf->pid,
+  		"parent pid", s->inf->ppid,
+  		"uptime", uptime);
+        FREE(uptime);
+        if(Run.doprocess)	{
+  	out_print(res,
+  		  "  %-33s %d\n"
+  		  "  %-33s %ld\n"
+  		  "  %-33s %ld\n"
+  		  "  %-33s %.1f%%\n"
 		  "  %-33s %.1f%%\n"
 		  "  %-33s %.1f%%\n"
 		  "  %-33s %.1f%%\n",
@@ -2247,39 +2263,41 @@ static void status_service_txt(Service_T s, HttpResponse res) {
 		  "memory percent", s->inf->mem_percent/10.0,
 		  "memory percent total", s->inf->total_mem_percent/10.0,
 		  "cpu percent", s->inf->cpu_percent/10.0,
-		  "cpu percent total", s->inf->total_cpu_percent/10.0);
+  		  "cpu percent total", s->inf->total_cpu_percent/10.0);
+        }
       }
-    }
-    if(s->type == TYPE_HOST && s->icmplist) {
-      Icmp_T i;
-      for(i= s->icmplist; i; i= i->next) {
-	out_print(res,
-		  "  %-33s %.3fs [%s]\n",
-		  "icmp response time", i->is_available?i->response:-1.,
-		  icmpnames[i->type]);
+      if(s->type == TYPE_HOST && s->icmplist) {
+        Icmp_T i;
+        for(i= s->icmplist; i; i= i->next) {
+  	out_print(res,
+  		  "  %-33s %.3fs [%s]\n",
+  		  "icmp response time", i->is_available?i->response:-1.,
+  		  icmpnames[i->type]);
+        }
       }
-    }
-    if((s->type == TYPE_HOST || s->type == TYPE_PROCESS) && s-> portlist) {
-      Port_T p;
-      for(p= s->portlist; p; p= p->next) {
-	if(p->family == AF_INET) {
-	  out_print(res,
-		    "  %-33s %.3fs to %s:%d%s [%s%s]\n",
-		    "port response time", p->is_available?p->response:-1., 
-		    p->hostname,
+      if((s->type == TYPE_HOST || s->type == TYPE_PROCESS) && s-> portlist) {
+        Port_T p;
+        for(p= s->portlist; p; p= p->next) {
+  	if(p->family == AF_INET) {
+  	  out_print(res,
+  		    "  %-33s %.3fs to %s:%d%s [%s%s]\n",
+  		    "port response time", p->is_available?p->response:-1., 
+  		    p->hostname,
 		    p->port, p->request?p->request:"", p->protocol->name,
-		    p->SSL.use_ssl?" via SSL":"");
-	} else if(p->family == AF_UNIX) {
-	  out_print(res,
-		    "  %-33s %.3fs to %s [%s]\n",
-		    "unix socket response time", p->is_available?p->response:-1.,
-		    p->pathname, p->protocol->name);
-	}
+  		    p->SSL.use_ssl?" via SSL":"");
+  	} else if(p->family == AF_UNIX) {
+  	  out_print(res,
+  		    "  %-33s %.3fs to %s [%s]\n",
+  		    "unix socket response time", p->is_available?p->response:-1.,
+  		    p->pathname, p->protocol->name);
+  	}
+        }
       }
     }
+    ctime_r(&s->collected, time);
+    out_print(res, "  %-33s %s\n", "data collected", time);
   }
-  ctime_r(&s->collected, time);
-  out_print(res, "  %-33s %s\n", "data collected", time);
+  FREE(status);
 }
 
 
