@@ -80,7 +80,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: monitor.c,v 1.119 2005/02/13 19:01:45 martinp Exp $
+ *  @version \$Id: monitor.c,v 1.120 2005/04/05 19:52:57 martinp Exp $
  *
  *  @file
  */
@@ -380,7 +380,9 @@ static void do_action(char **args) {
     log("Reinitializing monit daemon\n", prog);
     kill_daemon(SIGHUP);
   } else if(IS(action, "status")) {
-    status();
+    status(LEVEL_NAME_FULL);
+  } else if(IS(action, "summary")) {
+    status(LEVEL_NAME_SUMMARY);
   } else if(IS(action, "quit")) {
     kill_daemon(SIGTERM);
   } else if(IS(action, "validate")) {
@@ -625,7 +627,8 @@ static void help() {
   printf(" unmonitor all  - Disable monitoring of all services\n");
   printf(" unmonitor name - Only disable monitoring of the named service\n");
   printf(" reload         - Reinitialize monit\n");
-  printf(" status         - Print status information for each service\n");
+  printf(" status         - Print full status information for each service\n");
+  printf(" summary        - Print short status information for each service\n");
   printf(" quit           - Kill monit daemon process\n");
   printf(" validate       - Check all services and start if not running\n");
   printf("\n");
