@@ -117,6 +117,7 @@
 #define ACTION_EXEC        4
 #define ACTION_UNMONITOR   5
 #define ACTION_START       6
+#define ACTION_MONITOR     7
 
 #define TYPE_DEVICE        0
 #define TYPE_DIRECTORY     1
@@ -154,6 +155,12 @@
 #define PROTOCOL_HTTP      1
 #define PROTOCOL_HTTPS     2
 
+#define LEVEL_FULL         0
+#define LEVEL_SUMMARY      1
+
+#define LEVEL_NAME_FULL    "full"
+#define LEVEL_NAME_SUMMARY "summary"
+
 /** ------------------------------------------------- Special purpose macros */
 
 
@@ -726,7 +733,7 @@ void  control_service_daemon(const char *, const char *);
 void  setup_dependants();
 void  reset_depend();
 void  spawn(Service_T, Command_T, const char *);
-void  status();
+void  status(char *);
 int   log_init() ;
 void  log_log(const char *, ...) ;
 void  log_close();
@@ -765,7 +772,7 @@ int  sha_md5_stream (FILE *, void *, void *);
 void reset_procinfo(Service_T);
 int  check_service_status(Service_T);
 void printhash(char *);  
-char *status_xml(Event_T);
+char *status_xml(Event_T, short);
 void handle_collector(Event_T);
 int  do_wakeupcall();
 
