@@ -34,22 +34,24 @@
 #include "protocol.h"
 
 /* Private variables */
+static Protocol_T myapache_status= NULL;
 static Protocol_T mydefault= NULL;
-static Protocol_T myhttp= NULL;
-static Protocol_T myftp= NULL;
-static Protocol_T mysmtp= NULL;
-static Protocol_T mypop= NULL;
-static Protocol_T myimap= NULL;
-static Protocol_T mynntp= NULL;
-static Protocol_T myssh= NULL;
+static Protocol_T mydns= NULL;
 static Protocol_T mydwp= NULL;
+static Protocol_T myftp= NULL;
+static Protocol_T mygeneric= NULL;
+static Protocol_T myhttp= NULL;
+static Protocol_T myimap= NULL;
 static Protocol_T myldap2= NULL;
 static Protocol_T myldap3= NULL;
+static Protocol_T mymysql= NULL;
+static Protocol_T mynntp= NULL;
+static Protocol_T myntp3= NULL;
+static Protocol_T mypop= NULL;
+static Protocol_T mysmtp= NULL;
+static Protocol_T myssh= NULL;
 static Protocol_T myrdate= NULL;
 static Protocol_T myrsync= NULL;
-static Protocol_T mygeneric= NULL;
-static Protocol_T myapache_status= NULL;
-static Protocol_T myntp3= NULL;
 
 
 /**
@@ -58,7 +60,7 @@ static Protocol_T myntp3= NULL;
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: protocol.c,v 1.21 2005/01/28 17:54:33 martinp Exp $
+ *  @version \$Id: protocol.c,v 1.23 2005/04/03 11:56:51 martinp Exp $
  *
  *  @file
  */
@@ -69,46 +71,28 @@ static Protocol_T myntp3= NULL;
 
 void gc_protocols() {
 
-  FREE(mydefault); 
-  FREE(myhttp);    
-  FREE(myftp);     
-  FREE(mysmtp);    
-  FREE(mypop);     
-  FREE(myimap);    
-  FREE(mynntp);    
-  FREE(myssh);     
-  FREE(mydwp);     
-  FREE(myldap2);   
-  FREE(myldap3);   
-  FREE(myrdate);   
-  FREE(myrsync);   
-  FREE(mygeneric); 
   FREE(myapache_status);
+  FREE(mydefault);
+  FREE(mydns);
+  FREE(mydwp);
+  FREE(myftp);
+  FREE(mygeneric);
+  FREE(myhttp);
+  FREE(myimap);
+  FREE(myldap2);
+  FREE(myldap3);
+  FREE(mymysql);
+  FREE(mynntp);
   FREE(myntp3);
+  FREE(mypop);
+  FREE(mysmtp);
+  FREE(myssh);
+  FREE(myrdate);
+  FREE(myrsync);
 
 }
 
 
-void *create_default() {
-  if(mydefault == NULL) {
-    NEW(mydefault);
-    mydefault->name= "DEFAULT";
-    mydefault->check= check_default;
-  }
-  return mydefault;
-}
-
-
-void *create_http() {
-  if(myhttp == NULL) {
-    NEW(myhttp);
-    myhttp->name= "HTTP";
-    myhttp->check= check_http;
-  }
-  return myhttp;
-}
-
-
 void *create_apache_status() {
   if(myapache_status == NULL) {
     NEW(myapache_status);
@@ -119,73 +103,23 @@ void *create_apache_status() {
 }
 
 
-void *create_ftp() {
-  if(myftp == NULL) {
-    NEW(myftp);
-    myftp->name= "FTP";
-    myftp->check= check_ftp;
+void *create_default() {
+  if(mydefault == NULL) {
+    NEW(mydefault);
+    mydefault->name= "DEFAULT";
+    mydefault->check= check_default;
   }
-  return myftp;
+  return mydefault;
 }
 
 
-void *create_smtp() {
-  if(mysmtp == NULL) {
-    NEW(mysmtp);
-    mysmtp->name= "SMTP";
-    mysmtp->check= check_smtp;
+void *create_dns() {
+  if(mydns == NULL) {
+    NEW(mydns);
+    mydns->name= "DNS";
+    mydns->check= check_dns;
   }
-  return mysmtp;
-}
-
-
-void *create_pop() {
-  if(mypop == NULL) {
-    NEW(mypop);
-    mypop->name= "POP";
-    mypop->check= check_pop;
-  }
-  return mypop;
-}
-
-
-void *create_imap() {
-  if(myimap == NULL) {
-    NEW(myimap);
-    myimap->name= "IMAP";
-    myimap->check= check_imap;
-  }
-  return myimap;
-}
-
-
-void *create_ntp3() {
-  if(myntp3 == NULL) {
-    NEW(myntp3);
-    myntp3->name= "NTP3";
-    myntp3->check= check_ntp3;
-  }
-  return myntp3;
-}
-
-
-void *create_nntp() {
-  if(mynntp == NULL) {
-    NEW(mynntp);
-    mynntp->name= "NNTP";
-    mynntp->check= check_nntp;
-  }
-  return mynntp;
-}
-
-
-void *create_ssh() {
-  if(myssh == NULL) {
-    NEW(myssh);
-    myssh->name= "SSH";
-    myssh->check= check_ssh;
-  }
-  return myssh;
+  return mydns;
 }
 
 
@@ -199,6 +133,46 @@ void *create_dwp() {
 }
 
 
+void *create_ftp() {
+  if(myftp == NULL) {
+    NEW(myftp);
+    myftp->name= "FTP";
+    myftp->check= check_ftp;
+  }
+  return myftp;
+}
+
+
+void *create_generic() {
+  if(mygeneric == NULL) {
+    NEW(mygeneric);
+    mygeneric->name= "generic";
+    mygeneric->check= check_generic;
+  }
+  return mygeneric;
+}
+
+
+void *create_http() {
+  if(myhttp == NULL) {
+    NEW(myhttp);
+    myhttp->name= "HTTP";
+    myhttp->check= check_http;
+  }
+  return myhttp;
+}
+
+
+void *create_imap() {
+  if(myimap == NULL) {
+    NEW(myimap);
+    myimap->name= "IMAP";
+    myimap->check= check_imap;
+  }
+  return myimap;
+}
+
+
 void *create_ldap2() {
   if(myldap2 == NULL) {
     NEW(myldap2);
@@ -219,6 +193,66 @@ void *create_ldap3() {
 }
 
 
+void *create_mysql() {
+  if(mymysql == NULL) {
+    NEW(mymysql);
+    mymysql->name= "MYSQL";
+    mymysql->check= check_mysql;
+  }
+  return mymysql;
+}
+
+
+void *create_nntp() {
+  if(mynntp == NULL) {
+    NEW(mynntp);
+    mynntp->name= "NNTP";
+    mynntp->check= check_nntp;
+  }
+  return mynntp;
+}
+
+
+void *create_ntp3() {
+  if(myntp3 == NULL) {
+    NEW(myntp3);
+    myntp3->name= "NTP3";
+    myntp3->check= check_ntp3;
+  }
+  return myntp3;
+}
+
+
+void *create_pop() {
+  if(mypop == NULL) {
+    NEW(mypop);
+    mypop->name= "POP";
+    mypop->check= check_pop;
+  }
+  return mypop;
+}
+
+
+void *create_smtp() {
+  if(mysmtp == NULL) {
+    NEW(mysmtp);
+    mysmtp->name= "SMTP";
+    mysmtp->check= check_smtp;
+  }
+  return mysmtp;
+}
+
+
+void *create_ssh() {
+  if(myssh == NULL) {
+    NEW(myssh);
+    myssh->name= "SSH";
+    myssh->check= check_ssh;
+  }
+  return myssh;
+}
+
+
 void *create_rdate() {
   if(myrdate == NULL) {
     NEW(myrdate);
@@ -238,13 +272,3 @@ void *create_rsync() {
   return myrsync;
 }
 
-void *create_generic() {
-  if(mygeneric == NULL) {
-    NEW(mygeneric);
-    mygeneric->name= "generic";
-    mygeneric->check= check_generic;
-  }
-  return mygeneric;
-}
-
-
