@@ -43,44 +43,50 @@
 #define P_GENERIC        14
 #define P_APACHESTATUS   15
 #define P_NTP3           16
+#define P_MYSQL          17
+#define P_DNS            18
 
 void  gc_protocols();
 
 /* Protocol Factory routines */
+void* create_apache_status();
 void* create_default();
-void* create_http();
-void* create_ftp();
-void* create_smtp();
-void* create_pop();
-void* create_imap();
-void* create_ntp3();
-void* create_nntp();
-void* create_ssh();
+void* create_dns();
 void* create_dwp();
+void* create_ftp();
+void* create_generic();
+void* create_http();
+void* create_imap();
 void* create_ldap2();
 void* create_ldap3();
+void* create_mysql();
+void* create_nntp();
+void* create_ntp3();
+void* create_pop();
+void* create_smtp();
+void* create_ssh();
 void* create_rdate();
 void* create_rsync();
-void* create_generic();
-void* create_apache_status();
 
 /* "Package" locale Protocol routines */
+int check_apache_status(Socket_T);
 int check_default(Socket_T);
-int check_ssh(Socket_T);
+int check_dns(Socket_T);
 int check_dwp(Socket_T);
-int check_pop(Socket_T);
 int check_ftp(Socket_T);
+int check_generic(Socket_T);
 int check_http(Socket_T);
-int check_smtp(Socket_T);
 int check_imap(Socket_T);
-int check_ntp3(Socket_T);
-int check_nntp(Socket_T);
 int check_ldap2(Socket_T);
 int check_ldap3(Socket_T);
+int check_mysql(Socket_T);
+int check_nntp(Socket_T);
+int check_ntp3(Socket_T);
+int check_pop(Socket_T);
+int check_smtp(Socket_T);
+int check_ssh(Socket_T);
 int check_rdate(Socket_T);
 int check_rsync(Socket_T);
-int check_generic(Socket_T);
-int check_apache_status(Socket_T);
 
 
 #endif
