@@ -50,7 +50,7 @@
  * Implementation of the socket interface.
  * 
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
- * @version \$Id: socket.c,v 1.40 2005/02/12 23:44:07 martinp Exp $
+ * @version \$Id: socket.c,v 1.41 2005/04/03 11:56:51 martinp Exp $
  * @file
  */
 
@@ -340,6 +340,20 @@ int socket_get_socket(Socket_T S) {
 }
 
 
+/**
+ * Get the type of this socket.
+ * @param S A Socket object
+ * @return The socket type
+ */
+int socket_get_type(Socket_T S) {
+
+  ASSERT(S);
+  
+  return S->type;
+
+}
+
+
 /**
  * Get the Port object used to create this socket. If no Port object
  * was used this method returns NULL.
