@@ -101,6 +101,7 @@
 #include "base64.h"
 #include "alert.h"
 #include "process.h"
+#include "event.h"
 
 
 /* Private prototypes */
@@ -118,7 +119,7 @@ static int is_url_unsafe(unsigned char *);
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *  @author Michael Amster, <mamster@webeasy.com> 
  *
- *  @version \$Id: util.c,v 1.155 2005/03/23 23:37:49 hauk Exp $
+ *  @version \$Id: util.c,v 1.158 2005/04/11 22:27:53 martinp Exp $
  *  @file
  */
 
@@ -1605,6 +1606,22 @@ int Util_evalQExpression(int operator, int left, int right) {
 }
 
 
+/*
+ * This will enable service monitoring in the case that it was disabled.
+ * @param s A Service_T object
+ */
+void Util_monitorSet(Service_T s) {
+
+  ASSERT(s);
+
+  if(s->monitor == MONITOR_NOT)
+  {
+    s->monitor= MONITOR_INIT;
+    DEBUG("Monitoring enabled -- service %s\n", s->name);
+  }
+}
+
+
 /*
  * This will disable service monitoring in the case that it is enabled
  * @param s A Service_T object
@@ -1613,15 +1630,43 @@ void Util_monitorUnset(Service_T s) {
 
   ASSERT(s);
 
-  s->monitor= MONITOR_NOT;
+  if(s->monitor != MONITOR_NOT)
+  {
+    s->monitor= MONITOR_NOT;
+    DEBUG("Monitoring disabled -- service %s\n", s->name);
+  }
   s->nstart= 0;
   s->ncycle= 0;
+  s->error = EVENT_NULL;
   Util_resetInfo(s);
-  DEBUG("Monitoring disabled -- service %s\n", s->name);
-
 }
 
 
+/*
+ * Retun appropriate action id for string
+ * @param action A action string
+ * @return the action id
+ */
+int Util_getAction(const char *action) {
+
+  char *name;
+  /* the ACTION_IGNORE has index 0 => we will start on next item */
+  int   i = 1;
+
+  ASSERT(action);
+
+  for(name = actionnames[i]; strlen(actionnames[i]); i++)
+  {
+    if(IS(action, actionnames[i]))
+    {
+      /* supported action found */
+      return i;
+    }
+  }
+  /* the action was not found */
+  return ACTION_IGNORE;
+}
+
 /* ----------------------------------------------------------------- Private */
 
 
