@@ -90,7 +90,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: validate.c,v 1.135 2005/03/14 22:30:14 martinp Exp $
+ *  @version \$Id: validate.c,v 1.138 2005/04/13 07:37:46 martinp Exp $
  *  @file
  */
 
@@ -140,8 +140,6 @@ void validate() {
   time(&systeminfo.collected);
 
   for(s= servicelist; s; s= s->next) {
-    if(s->visited)
-      continue;
     LOCK(s->mutex)
       set_signal_block(&ns, &os);
       if(s->monitor && !check_skip(s) && !check_timeout(s)) {
@@ -292,6 +290,7 @@ int check_file(Service_T s) {
     s->inf->st_gid= stat_buf.st_gid;
     s->inf->st_size= stat_buf.st_size;
     s->inf->timestamp= MAX(stat_buf.st_mtime, stat_buf.st_ctime);
+    DEBUG("'%s' file existence check passed\n", s->name);
     Event_post(s, EVENT_NONEXIST, FALSE, s->action_NONEXIST,
       "'%s' file exist", s->name);
   }
@@ -301,6 +300,7 @@ int check_file(Service_T s) {
       "'%s' is not regular file", s->name);
     return FALSE;
   } else {
+    DEBUG("'%s' is regular file\n", s->name);
     Event_post(s, EVENT_INVALID, FALSE, s->action_INVALID,
       "'%s' is regular file", s->name);
   }
@@ -347,6 +347,7 @@ int check_directory(Service_T s) {
     s->inf->st_uid= stat_buf.st_uid;
     s->inf->st_gid= stat_buf.st_gid;
     s->inf->timestamp= MAX(stat_buf.st_mtime, stat_buf.st_ctime);
+    DEBUG("'%s' directory existence check passed\n", s->name);
     Event_post(s, EVENT_NONEXIST, FALSE, s->action_NONEXIST,
       "'%s' directory exist", s->name);
   }
@@ -356,6 +357,7 @@ int check_directory(Service_T s) {
       "'%s' is not directory", s->name);
     return FALSE;
   } else {
+    DEBUG("'%s' is directory\n", s->name);
     Event_post(s, EVENT_INVALID, FALSE, s->action_INVALID,
       "'%s' is directory", s->name);
   }
@@ -545,6 +547,7 @@ static void check_process_pid(Service_T s) {
     Event_post(s, EVENT_CHANGED, TRUE, s->action_PID,
       "'%s' process PID changed to %d", s->name, s->inf->pid);
   } else {
+    DEBUG("'%s' PID has not changed since last cycle\n", s->name);
     Event_post(s, EVENT_CHANGED, FALSE, s->action_PID,
       "'%s' PID has not changed", s->name);
   }
@@ -566,6 +569,7 @@ static void check_process_ppid(Service_T s) {
     Event_post(s, EVENT_CHANGED, TRUE, s->action_PPID,
       "'%s' process PPID changed to %d", s->name, s->inf->ppid);
   } else {
+    DEBUG("'%s' PPID has not changed since last cycle\n", s->name);
     Event_post(s, EVENT_CHANGED, FALSE, s->action_PPID,
       "'%s' PPID has not changed", s->name);
   }
@@ -813,7 +817,7 @@ static void check_perm(Service_T s) {
       "'%s' permission test failed for %s -- current permission is %o",
       s->name, s->path, s->inf->st_mode&07777);
   } else {
-    DEBUG("'%s' file permission check passed [current permission=%o]\n",
+    DEBUG("'%s' permission check passed [current permission=%o]\n",
       s->name, s->inf->st_mode&07777);
     Event_post(s, EVENT_PERMISSION, FALSE, s->perm->action,
       "'%s' permission passed", s->name);
@@ -833,7 +837,7 @@ static void check_uid(Service_T s) {
       "'%s' uid test failed for %s -- current uid is %d",
       s->name, s->path, (int)s->inf->st_uid);
   } else {
-    DEBUG("'%s' device uid check passed [current uid=%d]\n", s->name,
+    DEBUG("'%s' uid check passed [current uid=%d]\n", s->name,
           (int)s->inf->st_uid);
     Event_post(s, EVENT_UID, FALSE, s->uid->action, "'%s' uid passed", s->name);
   }
@@ -853,7 +857,7 @@ static void check_gid(Service_T s) {
       "'%s' gid test failed for %s -- current gid is %d",
       s->name, s->path, (int)s->inf->st_gid);
   } else {
-    DEBUG("'%s' device gid check passed [current gid=%d]\n", s->name,
+    DEBUG("'%s' gid check passed [current gid=%d]\n", s->name,
           (int)s->inf->st_gid);
     Event_post(s, EVENT_GID, FALSE, s->gid->action, "'%s' gid passed", s->name);
   }
@@ -1086,6 +1090,12 @@ static int check_skip(Service_T s) {
   if(!s->def_every)
     return FALSE;
   
+  if(s->visited) {
+    DEBUG("'%s' check skipped -- service already handled "
+          "in a dependency chain\n", s->name);
+    return TRUE;
+  }
+
   if(++s->nevery < s->every)
     return TRUE;
 
